@@ -216,7 +216,7 @@ class Step:
 
     title: str = attr.ib()
     description: Optional[str] = attr.ib(factory=str)
-    status: Status = attr.ib(default=Status.success)
+    status: str = attr.ib(default=Status.success)
     records: List[StepRecord] = attr.ib(factory=list)
 
     def assertion(
@@ -525,7 +525,7 @@ class AfterTestExecutionPayload(Payload):
     method: str = attr.ib()
     path: str = attr.ib()
     relative_path: str = attr.ib()
-    status: Status = attr.ib()
+    status: str = attr.ib()
     elapsed_time: float = attr.ib()
     result: Optional[TestResult] = attr.ib()
     test_suite_id: Optional[str] = attr.ib(default=None)
